#Install packages
install.packages("compindexR")
install.packages("readxl")
install.packages("devtools")
install.packages("openxlsx")
install.packages("ggplot2")
#Load packages
library(compindexR)
library(readxl)
library(devtools)
library(openxlsx)
library(ggplot2)

#First column as a row name
x<-data.frame(CI,row.names = TRUE)

#Changing destimulant into stimulant
x <- x %>%
  mutate(x1 = 1/x1)

x <- x %>%
  mutate(x2 = 1/x2)

wybrane<-x[3:8]
#Normalization
y<-scaling(x,method = "min-max")
#Caluclate CI
calc_average(y, avg_type = "simple") 

#Weight's optimalization 
ci_optimizer(y)
#Redcue the data set of those highly correlated variables
calc_compindex(y, avg_type = "simple",vif_based_calc=TRUE, si_diff = 0.005)
ci_optimizer(y)
#Optimizing algoritm
si_linear_exc(y, avg_type = "simple")
si_linear_exc_vif(y, avg_type = "simple", vif_threshold = 4.5)
#Calculating optimal values
z<-calc_compindex(y, avg_type = "simple",vif_based_calc=TRUE, si_diff = 0.005)
#Save value and ranks 
ranks <- z$ci
#Sort the results
ranks_sorted <- ranks[order(ranks$ranks), ]
#Visualization
barplot(ranks_sorted$ci, names.arg = row.names(ranks_sorted), col = "skyblue", main = "The health care situation", ylab = "composite indicator value", las = 2)

#ZSAve resutls to the new file
data<-tibble::rownames_to_column(ranks, "Country")
write.xlsx(data, "list.xlsx")

#Analysis for next year
CI2 <- read_excel("C:/Users/obrona/Downloads/Lab 10/Lab 10/CI.xlsx", 
                 sheet = "2015")

x2<-data.frame(CI2,row.names = TRUE)

x2 <- x2 %>%
  mutate(x1 = 1/x1)
x2 <- x2 %>%
  mutate(x2 = 1/x2)

wybrane2<-x2[3:7]

y2<-scaling(x2,method = "min-max")
calc_average(y2, avg_type = "simple") 
ci_optimizer(y2)
calc_compindex(y2, avg_type = "simple",vif_based_calc=TRUE, si_diff = 0.005)
ci_optimizer(y2)
si_linear_exc(y2, avg_type = "simple")
si_linear_exc_vif(y2, avg_type = "simple", vif_threshold = 4.5)
z2<-calc_compindex(y2, avg_type = "simple",vif_based_calc=TRUE, si_diff = 0.005)
ranks2 <- z2$ci
ranks_sorted2 <- ranks2[order(ranks2$ranks), ]
data2<-tibble::rownames_to_column(ranks2, "Country")

#Mwrge 2 datasets
merged_data <- merge(data, data2, by = "Country")
#Correlation among ranks
kendall_test <- cor.test(merged_data$ranks.x, merged_data$ranks.y, method = "kendall")
#Prezenetacja wartości wsp. tau Kendalla i odpowiadającej mu p-value
print(kendall_test$estimate)
print(kendall_test$p.value)

merged_data <- merged_data %>%
  mutate(dif = ci.y - ci.x)

ggplot(merged_data, aes(x = reorder(Country, -dif), y = dif, color = ifelse(dif >= 0, "green", "red"))) +
  geom_point(size = 3) +
  scale_color_identity() +
  geom_hline(yintercept = 0, linetype = "solid", color = "black", size = 0.2) + 
  labs(title = "Change in the composite indicator value", x = "Countries", y = "Difference") +
  theme_minimal() +
  theme(axis.text.x = element_text(angle = 45, hjust = 1))